@@ -1,8 +1,6 @@
 package Reply::App;
-BEGIN {
-  $Reply::App::AUTHORITY = 'cpan:DOY';
-}
-$Reply::App::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::App::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: command line app runner for Reply
@@ -119,7 +117,7 @@ Reply::App - command line app runner for Reply
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -161,7 +159,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
