@@ -1,8 +1,6 @@
 package Reply::Config;
-BEGIN {
-  $Reply::Config::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Config::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Config::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: config loading for Reply
@@ -59,7 +57,7 @@ Reply::Config - config loading for Reply
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -103,7 +101,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
