@@ -1,8 +1,6 @@
 package Reply::Plugin;
-BEGIN {
-  $Reply::Plugin::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: base class for Reply plugins
@@ -50,7 +48,7 @@ Reply::Plugin - base class for Reply plugins
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -236,7 +234,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
