@@ -1,8 +1,6 @@
 package Reply::Plugin::Autocomplete::Commands;
-BEGIN {
-  $Reply::Plugin::Autocomplete::Commands::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Autocomplete::Commands::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Autocomplete::Commands::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: tab completion for reply commands
@@ -36,7 +34,7 @@ Reply::Plugin::Autocomplete::Commands - tab completion for reply commands
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -54,7 +52,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
