@@ -1,8 +1,6 @@
 package Reply::Plugin::Autocomplete::Globals;
-BEGIN {
-  $Reply::Plugin::Autocomplete::Globals::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Autocomplete::Globals::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Autocomplete::Globals::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: tab completion for global variables
@@ -122,7 +120,7 @@ Reply::Plugin::Autocomplete::Globals - tab completion for global variables
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -141,7 +139,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
