@@ -1,8 +1,6 @@
 package Reply::Plugin::Autocomplete::Keywords;
-BEGIN {
-  $Reply::Plugin::Autocomplete::Keywords::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Autocomplete::Keywords::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Autocomplete::Keywords::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: tab completion for perl keywords
@@ -42,7 +40,7 @@ Reply::Plugin::Autocomplete::Keywords - tab completion for perl keywords
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -60,7 +58,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
