@@ -1,8 +1,6 @@
 package Reply::Plugin::Autocomplete::Lexicals;
-BEGIN {
-  $Reply::Plugin::Autocomplete::Lexicals::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Autocomplete::Lexicals::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Autocomplete::Lexicals::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: tab completion for lexical variables
@@ -62,7 +60,7 @@ Reply::Plugin::Autocomplete::Lexicals - tab completion for lexical variables
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -81,7 +79,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
