@@ -1,8 +1,6 @@
 package Reply::Plugin::Colors;
-BEGIN {
-  $Reply::Plugin::Colors::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Colors::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Colors::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: colorize output
@@ -91,7 +89,7 @@ Reply::Plugin::Colors - colorize output
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -118,7 +116,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
