@@ -1,8 +1,6 @@
 package Reply::Plugin::DataDumper;
-BEGIN {
-  $Reply::Plugin::DataDumper::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::DataDumper::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::DataDumper::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: format results using Data::Dumper
@@ -41,7 +39,7 @@ Reply::Plugin::DataDumper - format results using Data::Dumper
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -58,7 +56,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
