@@ -1,8 +1,6 @@
 package Reply::Plugin::DataPrinter;
-BEGIN {
-  $Reply::Plugin::DataPrinter::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::DataPrinter::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::DataPrinter::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: format results using Data::Printer
@@ -31,7 +29,7 @@ Reply::Plugin::DataPrinter - format results using Data::Printer
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -48,7 +46,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
