@@ -1,8 +1,6 @@
 package Reply::Plugin::Defaults;
-BEGIN {
-  $Reply::Plugin::Defaults::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Defaults::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Defaults::VERSION = '0.38';
 # XXX Eval::Closure imposes its own hints on things that are eval'ed at the
 # moment, but this may be fixed in the future
 BEGIN {
@@ -51,6 +49,7 @@ sub compile {
 
     my $env     = { map { %$_ } $self->publish('lexical_environment') };
     my $package = ($self->publish('package'))[-1];
+    $package = 'main' unless defined $package;
 
     my $prefix = "package $package;\n$PREFIX";
 
