@@ -1,8 +1,6 @@
 package Reply::Plugin::Editor;
-BEGIN {
-  $Reply::Plugin::Editor::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Editor::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Editor::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: command to edit the current line in a text editor
@@ -77,7 +75,7 @@ Reply::Plugin::Editor - command to edit the current line in a text editor
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -104,7 +102,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
