@@ -1,8 +1,6 @@
 package Reply::Plugin::Hints;
-BEGIN {
-  $Reply::Plugin::Hints::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Hints::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Hints::VERSION = '0.38';
 my $default_hints;
 my $default_hinthash;
 my $default_warning_bits;
@@ -85,7 +83,7 @@ Reply::Plugin::Hints - persists lexical hints across input lines
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -105,7 +103,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
