@@ -1,8 +1,6 @@
 package Reply::Plugin::Interrupt;
-BEGIN {
-  $Reply::Plugin::Interrupt::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Interrupt::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Interrupt::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: allows using Ctrl+C to interrupt long-running lines
@@ -40,7 +38,7 @@ Reply::Plugin::Interrupt - allows using Ctrl+C to interrupt long-running lines
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -58,7 +56,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
