@@ -1,8 +1,6 @@
 package Reply::Plugin::LexicalPersistence;
-BEGIN {
-  $Reply::Plugin::LexicalPersistence::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::LexicalPersistence::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::LexicalPersistence::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: persists lexical variables between lines
@@ -59,7 +57,7 @@ Reply::Plugin::LexicalPersistence - persists lexical variables between lines
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -78,7 +76,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
