@@ -1,8 +1,6 @@
 package Reply::Plugin::LoadClass;
-BEGIN {
-  $Reply::Plugin::LoadClass::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::LoadClass::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::LoadClass::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: attempts to load classes implicitly if possible
@@ -45,7 +43,7 @@ Reply::Plugin::LoadClass - attempts to load classes implicitly if possible
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -66,7 +64,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
