@@ -1,8 +1,6 @@
 package Reply::Plugin::Packages;
-BEGIN {
-  $Reply::Plugin::Packages::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Packages::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Packages::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: persist the current package between lines
@@ -67,7 +65,7 @@ Reply::Plugin::Packages - persist the current package between lines
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -88,7 +86,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
