@@ -1,8 +1,6 @@
 package Reply::Plugin::ReadLine;
-BEGIN {
-  $Reply::Plugin::ReadLine::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::ReadLine::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::ReadLine::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: use Term::ReadLine for user input
@@ -145,7 +143,7 @@ Reply::Plugin::ReadLine - use Term::ReadLine for user input
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -174,7 +172,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
