@@ -1,8 +1,6 @@
 package Reply::Plugin::Timer;
-BEGIN {
-  $Reply::Plugin::Timer::AUTHORITY = 'cpan:DOY';
-}
-$Reply::Plugin::Timer::VERSION = '0.37';
+our $AUTHORITY = 'cpan:DOY';
+$Reply::Plugin::Timer::VERSION = '0.38';
 use strict;
 use warnings;
 # ABSTRACT: time commands
@@ -55,7 +53,7 @@ Reply::Plugin::Timer - time commands
 
 =head1 VERSION
 
-version 0.37
+version 0.38
 
 =head1 SYNOPSIS
 
@@ -74,7 +72,7 @@ Jesse Luehrs <doy@tozt.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014 by Jesse Luehrs.
+This software is Copyright (c) 2015 by Jesse Luehrs.
 
 This is free software, licensed under:
 
